@@ -1,6 +1,6 @@
 package Image::Info::JPEG;
 
-# Copyright 1999, Gisle Aas.
+# Copyright 1999-2000, Gisle Aas.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -35,56 +35,69 @@ sub my_read
 
 sub process_file
 {
-    my($info, $fh) = @_;
+    my($info, $fh, $img_no) = @_;
+    $img_no ||= 0;
 
     my $soi = my_read($fh, 2);
     die "SOI missing" unless $soi eq "\xFF\xD8";
 
-    $info->push_info(0, "FileMediaType" => "image/jpeg");
-    $info->push_info(0, "FileExt" => "jpg");
+    $info->push_info($img_no, "file_media_type" => "image/jpeg");
+    $info->push_info($img_no, "file_ext" => "jpg");
 
     while (1) {
         my($ff, $mark, $len) = unpack("CCn", my_read($fh, 4));
         last if $ff != 0xFF;
         last if $mark == 0xDA || $mark == 0xD9;  # SOS/EOI
 	last if $len < 2;
-        process_chunk($info, $mark, my_read($fh, $len - 2));
+        process_chunk($info, $img_no, $mark, my_read($fh, $len - 2));
     }
 }
 
 sub process_chunk
 {
-    my($info, $mark, $data) = @_;
+    my($info, $img_no, $mark, $data) = @_;
     #printf "MARK 0x%02X, len=%d\n", $mark, length($data);
 
     if ($mark == 0xFE) {
-        $info->push_info(0, Comment => $data);
+        $info->push_info($img_no, Comment => $data);
     }
     elsif ($mark >= 0xE0 && $mark <= 0xEF) {
-        process_app($info, $mark, $data);
+        process_app($info, $mark, $data) if $img_no == 0;
     }
     elsif ($sof{$mark}) {
         my($precision, $height, $width, $num_comp) =
             unpack("CnnC", substr($data, 0, 6, ""));
-	$info->push_info(0, "JPEG_Type", $sof{$mark});
-	$info->push_info(0, "ImageWidth", $width);
-	$info->push_info(0, "ImageHeight", $height);
+	$info->push_info($img_no, "JPEG_Type", $sof{$mark});
+	$info->push_info($img_no, "width", $width);
+	$info->push_info($img_no, "height", $height);
 
 	for (1..$num_comp) {
-	    $info->push_info(0, "BitsPerSample", $precision);
+	    $info->push_info($img_no, "BitsPerSample", $precision);
 	}
-	$info->push_info(0, "SamplesPerPixel" => $num_comp);
+	$info->push_info($img_no, "SamplesPerPixel" => $num_comp);
+
+	# XXX need to consider JFIF/Adobe markers to determine this...
 	if ($num_comp == 1) {
-	    $info->push_info(0, "ColorType" => "Gray");
+	    $info->push_info($img_no, "color_type" => "Gray");
 	}
 	elsif ($num_comp == 3) {
-	    $info->push_info(0, "ColorType" => "RGB");  # or YCC??
+	    $info->push_info($img_no, "color_type" => "YCbCr");  # or RGB ?
+	}
+	elsif ($num_comp == 4) {
+	    $info->push_info($img_no, "color_type" => "CMYK");  # or YCCK ?
 	}
 
-	if (0) {
+	if (1) {
 	    while (length($data)) {
 		my($comp_id, $hv, $qtable) =
 		    unpack("CCC", substr($data, 0, 3, ""));
+		$comp_id = { 1 => "Y",
+			     2 => "Cb",
+			     3 => "Cr",
+			     82 => "R",
+			     71 => "G",
+			     66 => "B",
+			   }->{$comp_id} || $comp_id;
 		$info->push_info(0, "ColorComponents", [$comp_id, $hv, $qtable]);
 	    }
 	}
@@ -107,6 +120,9 @@ sub process_app
     elsif ($id eq "1-Exif\0") {
 	process_app1_exif($info, $data);
     }
+    elsif ($id eq "14-Adobe") {
+	process_app14_adobe($info, $data);
+    }
     else {
 	$info->push_info(0, "App$id", $data);
 	#printf "  %s\n", Data::Dump::dump($data);
@@ -123,21 +139,22 @@ sub process_app0_jfif
     my($ver_hi, $ver_lo, $units, $x_density, $y_density, $x_thumb, $y_thumb) =
 	unpack("CC C nn CC", substr($data, 0, 9, ""));
     $info->push_info(0, "JFIF_Version", sprintf("%d.%02d", $ver_hi, $ver_lo));
-    if ($x_density == $y_density) {
-	$info->push_info(0, "Resolution" => $x_density);
+
+    my $res = $x_density != $y_density || !$units
+	? "$x_density/$y_density" : $x_density;
+
+    if ($units) {
+	$units = { 0 => "pixels",
+		   1 => "dpi",
+		   2 => "dpcm"
+		 }->{$units} || "units-$units";
+	$res .= " $units";
     }
-    else {
-	$info->push_info(0, "XResolution" => $x_density);
-	$info->push_info(0, "YResolution" => $y_density);
-    }
-    $info->push_info(0, "ResolutionUnit" => { 0 => "pixels",
-					      1 => "dpi",
-					      2 => "dpcm"
-					    }->{$units} || $units);
+    $info->push_info(0, "resolution", $res);
 
     if ($x_thumb || $y_thumb) {
-	$info->push_info(1, "ImageWidth", $x_thumb);
-	$info->push_info(1, "ImageLength", $y_thumb);
+	$info->push_info(1, "width", $x_thumb);
+	$info->push_info(1, "height", $y_thumb);
 	$info->push_info(1, "ByteCount", length($data));
     }
 }
@@ -146,11 +163,20 @@ sub process_app0_jfxx
 {
     my($info, $data) = @_;
     my($code) = ord(substr($data, 0, 1, ""));
-    $info->push_info(1, "ImageType",
+    $info->push_info(1, "JFXX_ImageType",
 		     { 0x10 => "JPEG thumbnail",
 		       0x11 => "Bitmap thumbnail",
 		       0x13 => "RGB thumbnail",
 		     }->{$code} || "Unknown extention code $code");
+
+    if ($code == 0x10) {
+	eval {
+	    require IO::String;
+	    my $thumb_fh = IO::String->new($data);
+	    process_file($info, $thumb_fh, 1);
+	};
+	$info->push_info(1, "error" => $@) if $@;
+    }
 }
 
 sub process_app1_exif
@@ -171,6 +197,21 @@ sub process_app1_exif
 	    $info->push_info($i, $_->[0], $_->[3]);
 	}
     }
+
+    # XXX Should move XResolution/YResolution into 'resolution'
+
+    # XXX If we find JPEGInterchangeFormat/JPEGInterchangeFormatLngth,
+    # then we should apply process_file kind of recusively to extract
+    # information of this (thumbnail) image file...
+}
+
+sub process_app14_adobe
+{
+    my($info, $data) = @_;
+    my($version, $flags0, $flags1, $transform) = unpack("nnnC", $data);
+    $info->push_info(0, "AdobeTransformVersion" => $version);
+    $info->push_info(0, "AdobeTransformFlags" => [$flags0, $flags1]);
+    $info->push_info(0, "AdobeTransform" => $transform);
 }
 
 1;
